mod collector;

use axum::routing::get;
use axum::Router;
use axum::extract::Path;
use axum::http::StatusCode;
use axum::response::IntoResponse;
use collectors::PromMetric;

fn convert_into_metrics(data: Vec<impl PromMetric>) -> String {
    let metrics: Vec<String> = data
        .into_iter()
        .map(|w| w.to_metric_string())
        .collect();

    metrics.join("\n")
}

async fn worlds() -> impl IntoResponse {
    let resp = match collectors::player_count::get_player_count().await {
        Ok(r) => r,
        Err(_) => return (StatusCode::INTERNAL_SERVER_ERROR, "Nope".to_string())
    };

    (StatusCode::OK, convert_into_metrics(resp))
}

#[tokio::main]
async fn main() {
    let app = Router::new()
        .route("/worlds", get(worlds));
        // .route("/stats/:rsn", get(stats));

    println!("Starting...");

    axum::Server::bind(&"0.0.0.0:3030".parse().unwrap())
        .serve(app.into_make_service())
        .await
        .unwrap();
}
